tonalitytools.DoublingIndicator
===============================

.. inheritance-diagram:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.doublings

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.DoublingIndicator.DoublingIndicator.DoublingIndicator.__str__

   .. note:: Inherited from `__builtin__.object`
